#ifdef GL_ES
precision mediump float;
precision mediump sampler2D;
precision mediump samplerCube;
#endif

uniform vec3 u_PointLightSourceColor;
uniform float u_PointLightSourceRangeInverse;

#ifdef GL_ES
varying mediump vec2 v_textureCoordOut;

varying mediump vec3 v_normal;

varying mediump vec3 v_vertexToPointLightDirection;

// pool
varying mediump vec3 v_reflect;
varying mediump vec3 v_eyeVertex;

#else

varying vec2 v_textureCoordOut;

varying vec3 v_normal;

varying vec3 v_vertexToPointLightDirection;

// pool
varying vec3 v_reflect;
varying vec3 v_eyeVertex;

#endif

uniform vec4 u_color;

// pool

uniform samplerCube u_cubeTex;
uniform sampler2D u_ballTex;

vec3 computeLighting(vec3 normalVector, vec3 lightDirection, vec3 lightColor, float attenuation)
{
    float diffuse = max(dot(normalVector, lightDirection), 0.0);
    vec3 diffuseColor = lightColor  * diffuse * attenuation;

    return diffuseColor;
}

void main(void)
{
    
    vec3 normal  = normalize(v_normal);

    // 本来是u_AmbientLightSourceColor 
    vec4 combinedColor = vec4(0.47, 0.51, 0.55, 1.0);

//     Point light contribution

    vec3 ldir = v_vertexToPointLightDirection * u_PointLightSourceRangeInverse;
    float attenuation = clamp(1.0 - dot(ldir, ldir), 0.0, 1.0);
    combinedColor.xyz += computeLighting(normal, normalize(v_vertexToPointLightDirection), u_PointLightSourceColor, attenuation);

    vec4 color = texture2D(CC_Texture0, v_textureCoordOut) * u_color * combinedColor;

    vec3 normalizedLightDirection = normalize(v_vertexToPointLightDirection);

    // 计算漫反射
    float diffuseStrength = dot(normalizedLightDirection, v_normal);
    diffuseStrength = clamp(diffuseStrength, 0.25, 0.9);

    // 计算环境光
    vec3 ambient = 0.3 * diffuseStrength * textureCube(u_cubeTex, v_reflect).rgb;

    // 最终颜色计算,去掉了高光小亮点
    vec3 finalColor = 0.9*color.xyz + ambient;
    gl_FragColor = vec4(finalColor, 1.0);
    
//    gl_FragColor = 0.2 * textureCube(u_cubeTex, v_reflect) + 0.8 * texture2D(u_ballTex, v_textureCoordOut);
}
